@@ -2,11 +2,11 @@
   Fast parser and formatter for HTTP Date.
 -}
 module Network.HTTP.Date (
-    module Network.HTTP.Date.Types
+    module Network.HTTP.Date.Converter
+  , module Network.HTTP.Date.Types
   -- * Utility functions
   , parseHTTPDate
   , formatHTTPDate
-  , epochTimeToHTTPDate
   ) where
 
 import Network.HTTP.Date.Converter
