@@ -1,12 +1,17 @@
+{-# LANGUAGE CPP #-}
+
 module Model where
 
 import Data.ByteString (ByteString)
 import qualified Data.ByteString.Char8 as BS8
 import Data.Time
 import Data.Time.Clock.POSIX
-import System.Locale
 import System.Posix.Types
 
+#if !MIN_VERSION_time(1,5,0)
+import System.Locale
+#endif
+
 epochTimeToUtcTime :: EpochTime -> UTCTime
 epochTimeToUtcTime = posixSecondsToUTCTime . realToFrac
 
